From grant_lkml@dodo.com.au Wed May 11 19:01:01 2005
From: Grant Coady <grant_lkml@dodo.com.au>
To: sensors@Stimpy.netroedge.com
Cc: greg@kroah.com, khali@linux-fr.org
Subject: I2C: sysfs names: rename to cpu0_vid, take 3
Date: Thu, 12 May 2005 11:59:29 +1000
Message-ID: <p1e581lnv6oftmknftuj2ess28fuida1d8@4ax.com>

This small patch changes two drivers, adm1025 and adm1026, to 
report vid as cpu0_vid sysfs name as used by the other drivers.

Added duplicated names and six month warning for old names to 
be removed as requested.  Compile tested.

Signed-off-by: Grant Coady <gcoady@gmail.com>
Signed-off-by: Greg Kroah-Hartman <gregkh@suse.de>

---
 Documentation/feature-removal-schedule.txt |   10 ++++++++++
 drivers/i2c/chips/adm1025.c                |    4 ++++
 drivers/i2c/chips/adm1026.c                |    5 ++++-
 3 files changed, 18 insertions(+), 1 deletion(-)

--- gregkh-2.6.orig/Documentation/feature-removal-schedule.txt	2005-05-09 09:06:53.000000000 -0700
+++ gregkh-2.6/Documentation/feature-removal-schedule.txt	2005-05-13 13:49:41.000000000 -0700
@@ -63,3 +63,13 @@
 	people, who might be using implementations that I am not aware
 	of, to adjust to this upcoming change.
 Who:	Paul E. McKenney <paulmck@us.ibm.com>
+
+---------------------------
+
+What:	i2c sysfs name change: in1_ref, vid deprecated in favour of cpu0_vid
+When:	November 2005
+Files:	drivers/i2c/chips/adm1025.c, drivers/i2c/chips/adm1026.c
+Why:	Match the other drivers' name for the same function, duplicate names
+	will be available until removal of old names.
+Who:	Grant Coady <gcoady@gmail.com>
+
--- gregkh-2.6.orig/drivers/i2c/chips/adm1025.c	2005-05-13 11:37:11.000000000 -0700
+++ gregkh-2.6/drivers/i2c/chips/adm1025.c	2005-05-13 13:49:41.000000000 -0700
@@ -286,7 +286,9 @@
 	struct adm1025_data *data = adm1025_update_device(dev);
 	return sprintf(buf, "%u\n", vid_from_reg(data->vid, data->vrm));
 }
+/* in1_ref is deprecated in favour of cpu0_vid, remove after 2005-11-11 */
 static DEVICE_ATTR(in1_ref, S_IRUGO, show_vid, NULL);
+static DEVICE_ATTR(cpu0_vid, S_IRUGO, show_vid, NULL);
 
 static ssize_t show_vrm(struct device *dev, char *buf)
 {
@@ -436,7 +438,9 @@
 	device_create_file(&new_client->dev, &dev_attr_temp1_max);
 	device_create_file(&new_client->dev, &dev_attr_temp2_max);
 	device_create_file(&new_client->dev, &dev_attr_alarms);
+	/* in1_ref is deprecated, remove after 2005-11-11 */
 	device_create_file(&new_client->dev, &dev_attr_in1_ref);
+	device_create_file(&new_client->dev, &dev_attr_cpu0_vid);
 	device_create_file(&new_client->dev, &dev_attr_vrm);
 
 	/* Pin 11 is either in4 (+12V) or VID4 */
--- gregkh-2.6.orig/drivers/i2c/chips/adm1026.c	2005-05-13 11:37:11.000000000 -0700
+++ gregkh-2.6/drivers/i2c/chips/adm1026.c	2005-05-13 13:49:41.000000000 -0700
@@ -1266,8 +1266,9 @@
 	struct adm1026_data *data = adm1026_update_device(dev);
 	return sprintf(buf,"%d\n", vid_from_reg(data->vid & 0x3f, data->vrm));
 }
-
+/* vid deprecated in favour of cpu0_vid, remove after 2005-11-11 */
 static DEVICE_ATTR(vid, S_IRUGO, show_vid_reg, NULL);
+static DEVICE_ATTR(cpu0_vid, S_IRUGO, show_vid_reg, NULL);
 
 static ssize_t show_vrm_reg(struct device *dev, char *buf)
 {
@@ -1707,7 +1708,9 @@
 	device_create_file(&new_client->dev, &dev_attr_temp1_crit_enable);
 	device_create_file(&new_client->dev, &dev_attr_temp2_crit_enable);
 	device_create_file(&new_client->dev, &dev_attr_temp3_crit_enable);
+	/* vid deprecated in favour of cpu0_vid, remove after 2005-11-11 */
 	device_create_file(&new_client->dev, &dev_attr_vid);
+	device_create_file(&new_client->dev, &dev_attr_cpu0_vid);
 	device_create_file(&new_client->dev, &dev_attr_vrm);
 	device_create_file(&new_client->dev, &dev_attr_alarms);
 	device_create_file(&new_client->dev, &dev_attr_alarm_mask);
